Learn R Programming

unheadr (version 0.3.2)

annotate_mf_all: Annotate meaningful formatting for all cells

Description

Turns cell formatting into annotations for all values across all variables.

Usage

annotate_mf_all(xlfilepath)

Value

A tibble with meaningful formatting embedded as text for all rows and columns.

Arguments

xlfilepath

Path to a single-sheet spreadsheet file (xls or xlsx).

Details

At this point, seven popular approaches for meaningful formatting (bold, colored text, italic, strikethrough, underline, double underline, and cell highlighting) are hardcoded in the function. sheets, skip, and range arguments for spreadsheet input are not supported. The hex8 code of the fill color used for text color and cell highlighting is also appended in the output. Ensure the data in the spreadsheet are rectangular before running.

Examples

Run this code
example_spreadsheet <- system.file("extdata/boutiques.xlsx", package = "unheadr")
annotate_mf_all(example_spreadsheet)

Run the code above in your browser using DataLab