At this point, seven popular approaches for meaningful
formatting (bold, colored text, italic, strikethrough, underline, double underline, and cell highlighting) are hardcoded in
the function. sheets, skip, and range arguments for spreadsheet input
are not supported. The hex8 code of the fill color used for text color and cell
highlighting is also appended in the output. Ensure the data in the
spreadsheet are rectangular before running.